Access management

Access Management

Users

class illumio.accessmanagement.User[source]

Represents a user object in the PCE.

Roles

class illumio.accessmanagement.Role[source]

Represents a role in the PCE.

Roles are read-only and define sets of capabilities.

Permissions

class illumio.accessmanagement.Permission[source]

Represents an RBAC permission in the PCE.

Permissions define access control bindings between auth security principals, roles, and scopes.

Service Accounts

class illumio.accessmanagement.ServiceAccount[source]

Represents a service account in the PCE.

Service accounts provide API access credentials for automated systems.

Auth Security Principals

class illumio.accessmanagement.AuthSecurityPrincipal[source]

Represents an auth security principal in the PCE.

Auth security principals map external identity provider groups to PCE permissions.

Access Restrictions

class illumio.accessmanagement.AccessRestriction[source]

Represents an access restriction in the PCE.

Access restrictions limit what IP ranges can access the PCE management API.